@@ -6,7 +6,7 @@ except ImportError:
 from alembic import context
 from sqlalchemy import engine_from_config, pool
 from logging.config import fileConfig
-from atramhasis.models import Base
+from atramhasis.data.models import Base
 from skosprovider_sqlalchemy.models import Base as SkosBase
 from sqlalchemy.schema import MetaData
 from os import path
@@ -56,7 +56,7 @@ def run_migrations_offline():
 
     """
     url = config.get_main_option("sqlalchemy.url")
-    context.configure(url=url)
+    context.configure(url=url, render_as_batch=True)
 
     with context.begin_transaction():
         context.run_migrations()
@@ -82,7 +82,8 @@ def run_migrations_online():
     connection = engine.connect()
     context.configure(
         connection=connection,
-        target_metadata=metadata
+        target_metadata=metadata,
+        render_as_batch=True
     )
 
     try:
